@@ -9,11 +9,11 @@ log = logging.getLogger(__name__)
 def sync_tree(root, dest):
     for child in root.children:
         path = "%s%s" % (dest, child.root_path)
-        if not os.path.exists(path):
+        if not os.path.exists(path):        
             os.makedirs(path)
-        if child.project is not None:
+        if child.is_leaf:
             clone_or_pull_project(child, path)
-        if child.group is not None:
+        if not child.is_leaf:
             sync_tree(child, dest)
 
 def is_git_repo(path):
@@ -44,7 +44,7 @@ def clone_or_pull_project(node, path):
         '''
         log.info("cloning new project %s", path)
         try:
-            git.Repo.clone_from(node.project.ssh_url_to_repo, path)
+            git.Repo.clone_from(node.url, path)
         except KeyboardInterrupt:
             log.error("User interrupted")
             sys.exit(0)        
